@@ -1,4 +1,3 @@
-from __future__ import absolute_import, unicode_literals
 import ast
 import io
 import os
@@ -15,10 +14,6 @@ import contextlib
 from distutils.errors import DistutilsOptionError, DistutilsFileError
 from packaging.version import LegacyVersion, parse
 from packaging.specifiers import SpecifierSet
-from six import string_types, PY3
-
-
-__metaclass__ = type
 
 
 class StaticModule:
@@ -324,7 +319,7 @@ class ConfigHandler:
         """
         include_directive = 'file:'
 
-        if not isinstance(value, string_types):
+        if not isinstance(value, str):
             return value
 
         if not value.startswith(include_directive):
@@ -559,7 +554,7 @@ class ConfigMetadataHandler(ConfigHandler):
         if callable(version):
             version = version()
 
-        if not isinstance(version, string_types):
+        if not isinstance(version, str):
             if hasattr(version, '__iter__'):
                 version = '.'.join(map(str, version))
             else:
@@ -614,9 +609,6 @@ class ConfigOptionsHandler(ConfigHandler):
             return self._parse_list(value)
 
         findns = trimmed_value == find_directives[1]
-        if findns and not PY3:
-            raise DistutilsOptionError(
-                'find_namespace: directive is unsupported on Python < 3.3')
 
         # Read function arguments from a dedicated section.
         find_kwargs = self.parse_section_packages__find(
